Prometheus
----------

.. automodule:: gordo.server.prometheus.metrics
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: gordo.server.prometheus.server
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: gordo.server.prometheus.gunicorn_config
    :members:
    :undoc-members:
    :show-inheritance:
